@@ -1,9 +1,10 @@
 #ifndef QvkMagnifier_H 
 #define QvkMagnifier_H
 
+#include <QScreen>
+#include <QPixmap>
 #include <QDialog>
 #include <QLabel>
-#include <QPixmap>
 #include <QDesktopWidget>
 #include <QDebug>
 #include <QApplication>
@@ -13,9 +14,8 @@
 #include <QPropertyAnimation>
 #include <QPushButton>
 
-
 #include "ui_QvkMagnifierDialog.h"
-
+#include "QvkSettings.h"
 
 class QvkMagnifier: public QDialog
 { 
@@ -24,10 +24,10 @@ public:
   QvkMagnifier();
   virtual ~QvkMagnifier();
   
-  
 public slots:
   void getDialogMagnifier( QWidget *parent );
-
+  void magnifierShow();
+  int getFormValue();
   
 private slots:
   void closeEvent( QCloseEvent * event );
@@ -44,7 +44,6 @@ private slots:
 
   void closeDialog();
   
-
 protected:  
 
   
@@ -63,8 +62,10 @@ private:
   int faktor;
   int formValue;
   //QDialog *dialog;
-  
   QDialog *newDialog;
+  QTimer *timer;
+  QvkSettings vkSettings;
+  
 };
 
 
