@@ -41,6 +41,13 @@
         <translation>Cancelar</translation>
     </message>
 </context>
+<context>
+    <name>NoPlayerDialog</name>
+    <message>
+        <source>Please install a videoplayer</source>
+        <translation>Instale o reprodutor de vídeo</translation>
+    </message>
+</context>
 <context>
     <name>QvkMail</name>
     <message>
@@ -66,6 +73,14 @@
         <source>Show over fullscreen</source>
         <translation>Mostrar em tela cheia</translation>
     </message>
+    <message>
+        <source>Right click for menu</source>
+        <translation>Clique com o botão direito para abrir o menu</translation>
+    </message>
+    <message>
+        <source>User-defined</source>
+        <translation>Definido pelo usuário</translation>
+    </message>
 </context>
 <context>
     <name>WebcamBusyDialog</name>
@@ -90,6 +105,13 @@
         <translation>Desconhecido</translation>
     </message>
 </context>
+<context>
+    <name>regionselection</name>
+    <message>
+        <source>doubleclick extended to the edge</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>screencast</name>
     <message>
@@ -110,7 +132,7 @@
     </message>
     <message>
         <source>Audio</source>
-        <translation>Audio</translation>
+        <translation>Áudio</translation>
     </message>
     <message>
         <source>Alsa</source>
@@ -142,7 +164,7 @@
     </message>
     <message>
         <source>Vokoscreen minimized when recording starts</source>
-        <translation>Vokoscreen minimizado quando iniciar gravação</translation>
+        <translation>Minimizar o Vokoscreen ao iniciar a gravação</translation>
     </message>
     <message>
         <source>Start</source>
@@ -154,7 +176,7 @@
     </message>
     <message>
         <source>Pause</source>
-        <translation>pausa</translation>
+        <translation>Pausar</translation>
     </message>
     <message>
         <source>Play</source>
@@ -202,7 +224,7 @@
     </message>
     <message>
         <source>Select one or more devices</source>
-        <translation>Selecione um mais dispositivos</translation>
+        <translation>Selecione um ou mais dispositivos</translation>
     </message>
     <message>
         <source>Actual frames per second</source>
@@ -216,10 +238,6 @@
         <source>Homepage</source>
         <translation>Homepage</translation>
     </message>
-    <message>
-        <source>Mailinglist</source>
-        <translation>Lista de Email</translation>
-    </message>
     <message>
         <source>Support</source>
         <translation>Suporte</translation>
@@ -232,10 +250,6 @@
         <source>Frames</source>
         <translation>Frames</translation>
     </message>
-    <message>
-        <source>Beta openSUSE</source>
-        <translation>Beta openSUSE</translation>
-    </message>
     <message>
         <source>Donate</source>
         <translation>Doações</translation>
@@ -254,7 +268,7 @@
     </message>
     <message>
         <source>Show in systray</source>
-        <translation>Mostra no systray</translation>
+        <translation>Mostrar na área de notificação</translation>
     </message>
     <message>
         <source>New version available</source>
@@ -274,7 +288,7 @@
     </message>
     <message>
         <source>Select webcam</source>
-        <translation>Selecione webcam</translation>
+        <translation>Selecione a webcam</translation>
     </message>
     <message>
         <source>Mirrored</source>
@@ -288,5 +302,9 @@
         <source>All Displays</source>
         <translation>Todas as telas</translation>
     </message>
+    <message>
+        <source>Developer Homepage</source>
+        <translation>Página Web do desenvolvedor</translation>
+    </message>
 </context>
 </TS>
\ No newline at end of file
