@@ -41,6 +41,13 @@
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>NoPlayerDialog</name>
+    <message>
+        <source>Please install a videoplayer</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>QvkMail</name>
     <message>
@@ -66,6 +73,14 @@
         <source>Show over fullscreen</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Right click for menu</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>User-defined</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>WebcamBusyDialog</name>
@@ -90,6 +105,13 @@
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>regionselection</name>
+    <message>
+        <source>doubleclick extended to the edge</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>screencast</name>
     <message>
@@ -216,10 +238,6 @@
         <source>Homepage</source>
         <translation>Trang chủ</translation>
     </message>
-    <message>
-        <source>Mailinglist</source>
-        <translation>Danh sách email</translation>
-    </message>
     <message>
         <source>Support</source>
         <translation>Hỗ trợ</translation>
@@ -232,10 +250,6 @@
         <source>Frames</source>
         <translation>Khung ảnh</translation>
     </message>
-    <message>
-        <source>Beta openSUSE</source>
-        <translation>Bản thử nghiệm openSUSE</translation>
-    </message>
     <message>
         <source>Donate</source>
         <translation>Ủng hộ tài chính</translation>
@@ -288,5 +302,9 @@
         <source>All Displays</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Developer Homepage</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
