@@ -17,12 +17,11 @@
  */
 
 #include "screencast.h"
-//#include <QSplashScreen>
-#include <QtSingleApplication/qtsingleapplication.h>
 #include <QDebug>
 #include <QTranslator>
 #include <QLocale>
-#include <QLibraryInfo>
+//#include <QLibraryInfo>
+#include <QtSingleApplication>
 
 int main(int argc, char** argv)
 {
