@@ -17,43 +17,36 @@
  */
 
 #include "regionselection.h" 
-#include <QSettings>
 
-using namespace std;
-
-// Double Buffering
-//http://books.google.de/books?id=T373zcyFfvoC&pg=PA168&lpg=PA168&dq=qt+double+buffering&source=bl&ots=Wavv6fM_7D&sig=eOilngWo3WQzrrRPcoP4oOycWbE&hl=de&sa=X&ei=_hgAUoKNIcjwsgaiiIHgCw&ved=0CDEQ6AEwAA#v=onepage&q=qt%20double%20buffering&f=false
-
-/**
- * int x : 
- * int y :
- * int width :
- * int height :
- * int framewidth :
- */
 regionselection::regionselection()
 {
+  vkSettings.readAll();
+  
+  setAttribute ( Qt::WA_AlwaysShowToolTips );
+  setToolTip( tr( "double-click to maximize" ) );
+  
   handlePressed = NoHandle;
   handleUnderMouse = NoHandle;
   painter =  new QPainter();
   
-  // Muß in die vokoscreen.conf von Hand eingetragen werden. Keine GUI Unterstützung.
-  // NoShowInTaskBar=1
-  QSettings settings( "vokoscreen", "vokoscreen" );
-  settings.beginGroup( "Area" );
-    if ( settings.value( "NoShowInTaskBar", 1 ).toUInt() == 1 )
-    {
+//  Deaktiviert am 17.01.2014  
+//  Muß in die vokoscreen.conf von Hand eingetragen werden. Keine GUI Unterstützung.
+//  NoShowInTaskBar=1
+//  QSettings settings( "vokoscreen", "vokoscreen" );
+//  settings.beginGroup( "Area" );
+//    if ( settings.value( "NoShowInTaskBar", 1 ).toUInt() == 1 )
+//    {
       setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::ToolTip );
-      Setting_Area_NoShowInTaskBar = 1;
-    }
-    else
-    {
-      setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint );
-      Setting_Area_NoShowInTaskBar = 0;
-    }
-  settings.endGroup();
+//      Setting_Area_NoShowInTaskBar = 1;
+//    }
+//    else
+//    {
+//      setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint );
+//      Setting_Area_NoShowInTaskBar = 0;
+//    }
+//  settings.endGroup();
   
-  if( QX11Info::isCompositingManagerRunning() )
+  //if( QX11Info::isCompositingManagerRunning() ) // ******************************* vorerst ersatzlos gestrichen ********************************************************
     setAttribute( Qt::WA_TranslucentBackground, true );
 
   setMouseTracking( true );
@@ -74,6 +67,13 @@ regionselection::regionselection()
  
   // Framelock
   lockFrame( false );
+  
+  setGeometry( vkSettings.getAreaX(),
+               vkSettings.getAreaY(),
+               vkSettings.getAreaWidth() + borderLeft + borderRight + frameWidth,
+               vkSettings.getAreaHeight() + borderTop + borderBottom + frameWidth
+             );
+  
 }
 
 
@@ -81,7 +81,7 @@ regionselection::~regionselection()
 {
 }
 
-
+/*
 void regionselection::saveSettings()
 {
   QSettings settings( "vokoscreen", "vokoscreen" );   
@@ -89,6 +89,7 @@ void regionselection::saveSettings()
     settings.setValue( "NoShowInTaskBar", Setting_Area_NoShowInTaskBar );
   settings.endGroup();
 }
+*/
 
 void regionselection::HandleTopLeft()
 {
@@ -111,7 +112,7 @@ void regionselection::HandleTopLeft()
   
   QRectF rectangle = QRectF( borderLeft - radius + penHalf, borderTop - radius + penHalf, 2 * radius, 2 * radius );
   int startAngle = 0 * 16;
-  int spanAngle = 270 * 16;
+  int spanAngle = 360 * 16;
   painter->drawPie( rectangle, startAngle, spanAngle );
 
   // Begin Pfeil zeichnen
@@ -149,7 +150,7 @@ void regionselection::HandleTopMiddle()
   
   QRectF rectangle = QRectF( ( width() - borderLeft - borderRight ) / 2 + borderLeft - radius, borderTop - radius + penHalf, 2 * radius, 2 * radius );
   int startAngle = 0 * 16;
-  int spanAngle = 180 * 16;
+  int spanAngle = 360 * 16;
   painter->drawPie( rectangle, startAngle, spanAngle );
   painter->setPen( QPen( arrow, 2 ) );
   QPainterPath * painterPath = new QPainterPath();
@@ -183,7 +184,8 @@ void regionselection::HandleTopRight()
 
   QRectF rectangle = QRectF( width() - borderRight - radius - penHalf, borderTop - radius + penHalf, 2 * radius, 2 * radius );
   int startAngle = 180 * 16;
-  int spanAngle =  -270  * 16;
+  int spanAngle =  -360  * 16;
+  
   painter->drawPie( rectangle, startAngle, spanAngle );
 
   // Begin Pfeil zeichnen
@@ -225,7 +227,7 @@ void regionselection::HandleRightMiddle()
   
   QRectF rectangle = QRectF( width() - borderRight - radius - penHalf, ( height() - borderTop - borderBottom ) / 2 + borderTop - radius,  2 * radius, 2 * radius );
   int startAngle = 90 * 16;
-  int spanAngle =  -180  * 16;
+  int spanAngle =  -360  * 16;
   painter->drawPie( rectangle, startAngle, spanAngle ); 
   
    // Begin Pfeil zeichnen
@@ -266,7 +268,7 @@ void regionselection::HandleBottomRight()
   
   QRectF rectangle = QRectF( width() - borderRight - radius - penHalf, height() - borderBottom - radius - penHalf, 2 * radius, 2 * radius );
   int startAngle = 90 * 16;
-  int spanAngle =  -270  * 16;
+  int spanAngle =  -360  * 16;
   painter->drawPie( rectangle, startAngle, spanAngle );
   
   // Begin Pfeil zeichnen
@@ -309,7 +311,7 @@ void regionselection::HandleBottomMiddle()
 
   QRectF rectangle = QRectF( ( width() - borderLeft - borderRight ) / 2 + borderLeft - radius, height() - borderBottom - radius - penHalf, 2 * radius, 2 * radius );
   int startAngle = 0 * 16;
-  int spanAngle =  -180  * 16;
+  int spanAngle =  -360  * 16;
   painter->drawPie( rectangle, startAngle, spanAngle );
   
   // Begin Pfeil zeichnen
@@ -350,7 +352,7 @@ void regionselection::HandleBottomLeft()
 
   QRectF rectangle = QRectF( borderLeft - radius + penHalf, height() - borderBottom - radius - penHalf, 2 * radius, 2 * radius );
   int startAngle = 90 * 16;
-  int spanAngle =  270  * 16;
+  int spanAngle =  360  * 16;
   painter->drawPie( rectangle, startAngle, spanAngle );
 
   // Begin Pfeil zeichnen
@@ -393,7 +395,7 @@ void regionselection::HandleLeftMiddle()
 
   QRectF rectangle = QRectF( borderLeft - radius + penHalf, ( height() - borderTop - borderBottom ) / 2 + borderTop - radius, 2 * radius, 2 * radius );
   int startAngle = 90 * 16;
-  int spanAngle =  180  * 16;
+  int spanAngle =  360  * 16;
   painter->drawPie( rectangle, startAngle, spanAngle );
   
   // Begin Pfeil zeichnen
@@ -546,15 +548,19 @@ void regionselection::paintEvent( QPaintEvent *event )
     
     QRegion RegionWidget( 0, 0, width(), height() );
     
-    // RecordArea
-    QRegion RegionArea  ( borderLeft + frameWidth / 2,
-                          borderTop + frameWidth / 2,
-                          width() - ( borderLeft + frameWidth / 2 ) - ( borderRight + frameWidth / 2 ),
-                          height() - ( borderTop + frameWidth / 2 ) - ( borderBottom + frameWidth / 2 ) );
+    QRegion RegionArea  ( borderLeft + frameWidth / 2 + radius,
+                          borderTop + frameWidth / 2 + radius,
+                          width() - ( borderLeft + frameWidth / 2 ) - ( borderRight + frameWidth / 2 + 2 * radius ),
+                          height() - ( borderTop + frameWidth / 2 ) - ( borderBottom + frameWidth / 2 + 2 * radius) );
 
     // subtract the record Area
+    #ifdef QT4
     QRegion RegionNew = RegionWidget.subtract( RegionArea );
-
+    #endif
+    #ifdef QT5
+    QRegion RegionNew = RegionWidget.subtracted( RegionArea );
+    #endif
+    
     // Retrieves and merge display-area-size in record Area
     QRegion r1 = RegionNew.united( getPrintSizeRectForMask() );
     
@@ -576,8 +582,12 @@ void regionselection::paintEvent( QPaintEvent *event )
                           height() - ( borderTop + frameWidth / 2 ) - ( borderBottom + frameWidth / 2 ) );
 
     // subtract the record Area
+    #ifdef QT4
     QRegion RegionNew = RegionWidget.subtract( RegionArea );
-
+    #endif
+    #ifdef QT5
+    QRegion RegionNew = RegionWidget.subtracted( RegionArea );
+    #endif
     setMask( RegionNew );
   }
 
@@ -639,7 +649,7 @@ void regionselection::handlingFrameLock()
  */
 int regionselection::getX()
 {
-  return this->x(); 
+  return geometry().x(); 
 }
 
 
@@ -648,7 +658,7 @@ int regionselection::getX()
  */
 int regionselection::getY()
 {
-  return  this->y();
+  return  geometry().y();
 }
 
 
@@ -657,7 +667,7 @@ int regionselection::getY()
  */
 int regionselection::getXRecordArea()
 {
-  return this->x() + borderLeft + frameWidth / 2; 
+  return geometry().x() + borderLeft + frameWidth / 2; 
 }
 
 
@@ -666,7 +676,7 @@ int regionselection::getXRecordArea()
  */
 int regionselection::getYRecordArea()
 {
-  return  this->y() + borderTop + frameWidth / 2;
+  return  geometry().y() + borderTop + frameWidth / 2;
 }
 
 
@@ -675,7 +685,7 @@ int regionselection::getYRecordArea()
  */
 int regionselection::getHeight()
 {
-  return this->height() - borderTop - borderBottom - frameWidth; 
+  return height() - borderTop - borderBottom - frameWidth; 
 }
 
 
@@ -684,7 +694,7 @@ int regionselection::getHeight()
  */
 int regionselection::getWidth()
 {
-  return this->width() - borderLeft - borderRight - frameWidth; 
+  return width() - borderLeft - borderRight - frameWidth; 
 }
 
 
@@ -724,7 +734,7 @@ void regionselection::mouseMoveEvent( QMouseEvent *event )
   if ( ( event->x() > ( width() - borderLeft - borderRight ) / 2 + borderLeft - radius ) and
        ( event->x() < ( width() - borderLeft - borderRight ) / 2 + borderLeft + radius ) and
        ( event->y() > borderTop - radius ) and
-       ( event->y() < borderTop ) )
+       ( event->y() < borderTop + frameWidth + radius) )
   {
     setCursor( Qt::SizeVerCursor );  
     handleUnderMouse = TopMiddle;
@@ -741,7 +751,7 @@ void regionselection::mouseMoveEvent( QMouseEvent *event )
     return;
   }
   
-  if ( ( event->x() > width() - borderRight ) and
+  if ( ( event->x() > width() - borderRight - frameWidth - radius ) and
        ( event->x() < width() - borderRight + radius ) and
        ( event->y() > ( ( height() - borderTop - borderBottom ) / 2 + borderTop - radius ) ) and
        ( event->y() < ( ( height() - borderTop - borderBottom ) / 2 + borderTop + radius ) ) )
@@ -764,7 +774,7 @@ void regionselection::mouseMoveEvent( QMouseEvent *event )
   if ( ( event->x() > ( width() - borderLeft - borderRight ) / 2 + borderLeft - radius ) and 
        ( event->x() < ( width() - borderLeft - borderRight ) / 2 + borderLeft + radius ) and 
        ( event->y() < height() - borderBottom + radius ) and 
-       ( event->y() > height() - borderBottom ) )
+       ( event->y() > height() - borderBottom - frameWidth  - radius) )
   {
     setCursor( Qt::SizeVerCursor );
     handleUnderMouse = BottomMiddle;
@@ -829,10 +839,12 @@ void regionselection::moveTopLeft( QMouseEvent *event )
     mouseGlobalX = widgetX + widgetWidth + currentMouseLocalX - 200;
   
   // Maximale Größe begrenzen
-  if ( mouseGlobalY - currentMouseLocalY < 0 )
+//  if ( mouseGlobalY - currentMouseLocalY < 0 )
+  if ( mouseGlobalY - currentMouseLocalY < radius * -1 - frameWidth/2 )
     mouseGlobalY = widgetY + currentMouseLocalY;
   
-  if ( mouseGlobalX - currentMouseLocalX < 0 )  
+  //if ( mouseGlobalX - currentMouseLocalX < 0 )
+  if ( mouseGlobalX - currentMouseLocalX < radius * -1 - frameWidth/2 )
     mouseGlobalX = widgetX + currentMouseLocalX;
   
   // Neue Geometry des Dialogfenster setzen
@@ -861,7 +873,8 @@ void regionselection::moveTopMiddle( QMouseEvent *event )
     mouseGlobalY = widgetY + widgetHeight + currentMouseLocalY - 200;
   
   // Maximale Größe begrenzen
-  if ( mouseGlobalY - currentMouseLocalY < 0 )
+//  if ( mouseGlobalY - currentMouseLocalY < 0 )
+  if ( mouseGlobalY - currentMouseLocalY < radius * -1 - frameWidth/2 )
     mouseGlobalY = widgetY + currentMouseLocalY;
   
   // Neue Geometry des HauptWidget setzen
@@ -892,12 +905,13 @@ void regionselection::moveTopRight( QMouseEvent *event )
     mouseGlobalY = widgetY + widgetHeight + currentMouseLocalY - 200;
   
   // Maximale Größe begrenzen
-  if ( mouseGlobalY - currentMouseLocalY < 0 )
+  //if ( mouseGlobalY - currentMouseLocalY < 0 )
+  if ( mouseGlobalY - currentMouseLocalY < radius * -1 - frameWidth/2 )
     mouseGlobalY = widgetY + currentMouseLocalY;
   
   QDesktopWidget *desk = QApplication::desktop();
-  //if ( mouseGlobalX + currentMouseRightLocalX > desk->screenGeometry().width() )
-  if ( mouseGlobalX + currentMouseRightLocalX > desk->width() )
+  // if ( mouseGlobalX + currentMouseRightLocalX > desk->width() )
+  if ( mouseGlobalX + currentMouseRightLocalX > desk->width() - radius * -1 + frameWidth/2 )
     mouseGlobalX = widgetX + widgetWidth - currentMouseRightLocalX;
   
   // Neue Geometry des Fenster setzen
@@ -925,8 +939,8 @@ void regionselection::moveRightMiddle( QMouseEvent *event )
 
   // Maximale größe begrenzen
   QDesktopWidget *desk = QApplication::desktop();
-  //if ( mouseGlobalX + currentMouseRightLocalX > desk->screenGeometry().width() )
-  if ( mouseGlobalX + currentMouseRightLocalX > desk->width() )
+  //if ( mouseGlobalX + currentMouseRightLocalX > desk->width() )
+  if ( mouseGlobalX + currentMouseRightLocalX > desk->width() - radius * -1 + frameWidth/2)
     mouseGlobalX = widgetX + widgetWidth - currentMouseRightLocalX;
   
   this->setGeometry( widgetX,
@@ -957,12 +971,12 @@ void regionselection::moveBottomRight( QMouseEvent *event )
   
   // Maximale größe begrenzen
   QDesktopWidget *desk = QApplication::desktop();
-  //if ( mouseGlobalX + currentMouseRightLocalX > desk->screenGeometry().width() )
-  if ( mouseGlobalX + currentMouseRightLocalX > desk->width() )
+  //if ( mouseGlobalX + currentMouseRightLocalX > desk->width() )
+  if ( mouseGlobalX + currentMouseRightLocalX > desk->width() - radius * -1 + frameWidth/2 )
     mouseGlobalX = widgetX + widgetWidth - currentMouseRightLocalX;
   
-  //if ( mouseGlobalY + currentMouseRightLocalY > desk->screenGeometry().height() )
-  if ( mouseGlobalY + currentMouseRightLocalY > desk->height() )
+  //if ( mouseGlobalY + currentMouseRightLocalY > desk->height() )
+  if ( mouseGlobalY + currentMouseRightLocalY > desk->height() - radius * -1 + frameWidth/2 )
     mouseGlobalY = widgetY + widgetHeight - currentMouseRightLocalY;
   
   this->setGeometry( widgetX,
@@ -989,8 +1003,9 @@ void regionselection::moveBottomMiddle( QMouseEvent *event )
   
   // Maximale größe begrenzen
   QDesktopWidget *desk = QApplication::desktop();
-  //if ( mouseGlobalY + currentMouseRightLocalY > desk->screenGeometry().height() )
-  if ( mouseGlobalY + currentMouseRightLocalY > desk->height() )
+
+  //if ( mouseGlobalY + currentMouseRightLocalY > desk->height() )
+  if ( mouseGlobalY + currentMouseRightLocalY > desk->height() - radius * -1 + frameWidth/2)
     mouseGlobalY = widgetY + widgetHeight - currentMouseRightLocalY;
 
   this->setGeometry( widgetX,
@@ -1020,12 +1035,13 @@ void regionselection::moveBottomLeft( QMouseEvent *event )
     mouseGlobalX = widgetX + widgetWidth + currentMouseLocalX - 200;
 
   // Maximale Größe des Widget begrenzen
-  if ( mouseGlobalX - currentMouseLocalX < 0 )  
+  //if ( mouseGlobalX - currentMouseLocalX < 0 )  
+  if ( mouseGlobalX - currentMouseLocalX < radius * -1 - frameWidth/2 )
     mouseGlobalX = widgetX + currentMouseLocalX;
 
   QDesktopWidget *desk = QApplication::desktop();
-  //if ( mouseGlobalY + currentMouseRightLocalY > desk->screenGeometry().height() )
-  if ( mouseGlobalY + currentMouseRightLocalY > desk->height() )
+  //if ( mouseGlobalY + currentMouseRightLocalY > desk->height() )
+  if ( mouseGlobalY + currentMouseRightLocalY > desk->height() - radius * -1 + frameWidth/2 )
     mouseGlobalY = widgetY + widgetHeight - currentMouseRightLocalY;
   
   this->setGeometry( mouseGlobalX - currentMouseLocalX,
@@ -1051,7 +1067,8 @@ void regionselection::moveLeftMiddle( QMouseEvent *event )
     mouseGlobalX = widgetX + widgetWidth + currentMouseLocalX - 200;
   
   // Maximale Größe des Widget begrenzen
-  if ( mouseGlobalX - currentMouseLocalX < 0 )  
+  //if ( mouseGlobalX - currentMouseLocalX < 0 )  
+  if ( mouseGlobalX - currentMouseLocalX < radius * -1 - frameWidth/2)
     mouseGlobalX = widgetX + currentMouseLocalX;
   
   // Neue Geometry des Dialogfenster setzen
@@ -1079,22 +1096,19 @@ void regionselection::moveMiddle( QMouseEvent *event )
   {
     // Das Verschieben begrenzen
     // Top
-    if ( mouseGlobalY - currentMouseLocalY < 0 )
+    if ( mouseGlobalY - currentMouseLocalY < radius * -1 - frameWidth/2 )
       mouseGlobalY = widgetY + currentMouseLocalY;
-  
+
     // Right
-    //QDesktopWidget *desk = QApplication::desktop();
-    //if ( mouseGlobalX + currentMouseRightLocalX > desk->screenGeometry().width() )
-    if ( mouseGlobalX + currentMouseRightLocalX > desk->width() )
+    if ( mouseGlobalX + currentMouseRightLocalX > desk->width() - radius * -1 + frameWidth/2 )
       mouseGlobalX = widgetX + widgetWidth - currentMouseRightLocalX;
   
     // Bottom
-    //if ( mouseGlobalY + currentMouseRightLocalY > desk->screenGeometry().height() )
-    if ( mouseGlobalY + currentMouseRightLocalY > desk->height() )
+    if ( mouseGlobalY + currentMouseRightLocalY > desk->height() - radius * -1 + frameWidth/2 )
       mouseGlobalY = widgetY + widgetHeight - currentMouseRightLocalY;
     
     // Left
-    if ( mouseGlobalX - currentMouseLocalX < 0 )  
+    if ( mouseGlobalX - currentMouseLocalX < radius * -1 - frameWidth/2 )
       mouseGlobalX = widgetX + currentMouseLocalX;
   }
   
@@ -1139,3 +1153,82 @@ void regionselection::mouseReleaseEvent( QMouseEvent * event )
   handlePressed = NoHandle;
   event->accept();  
 }
+
+
+void regionselection::mouseDoubleClickEvent( QMouseEvent * event )
+{
+  (void)event;
+  QDesktopWidget *desk = QApplication::desktop();
+  
+  if ( handleUnderMouse == TopLeft )
+  {
+    setGeometry( 0 - radius - frameWidth / 2,
+		 0 - radius - frameWidth / 2,
+		 geometry().x() + geometry().width() + radius + frameWidth / 2,
+		 geometry().y() + geometry().height() + radius + frameWidth / 2 );
+  }
+  
+  if ( handleUnderMouse == TopMiddle )
+  {
+    setGeometry( geometry().x(),
+		 0 - radius - frameWidth / 2,
+		 geometry().width(),
+		 geometry().y() + geometry().height() + radius + frameWidth / 2 );
+  }
+
+  if ( handleUnderMouse == TopRight )
+  {
+    setGeometry( geometry().x(),
+		 0 - radius - frameWidth / 2,
+		 desk->width() - geometry().x() + radius + frameWidth / 2,
+		 geometry().y() + geometry().height() + radius + frameWidth / 2 );
+  }
+    
+  if ( handleUnderMouse == RightMiddle )
+  {
+    setGeometry( geometry().x(),
+                 geometry().y(),
+		 desk->width() - geometry().x() + radius + frameWidth / 2,
+		 geometry().height() );
+  }
+    
+  if ( handleUnderMouse == BottomRight )
+  {
+    setGeometry( geometry().x(),
+                 geometry().y(),
+		 desk->width() - geometry().x() + radius + frameWidth / 2,
+		 desk->height() - geometry().y() + radius + frameWidth / 2 );
+  }
+  
+  if ( handleUnderMouse == BottomMiddle )
+  {
+    setGeometry( geometry().x(),
+                 geometry().y(),
+ 		 geometry().width(),
+		 desk->height() - geometry().y() + radius + frameWidth / 2 );
+  }
+  
+  if ( handleUnderMouse == BottomLeft )
+  {
+    setGeometry( 0 - radius - frameWidth / 2,
+                 geometry().y(),
+		 geometry().x() + geometry().width() + radius + frameWidth / 2,
+		 desk->height() - geometry().y() + radius + frameWidth / 2 );
+  }
+
+  if ( handleUnderMouse == LeftMiddle )
+  {
+    setGeometry( 0 - radius - frameWidth / 2,
+                 geometry().y(),
+		 geometry().x() + geometry().width() + radius + frameWidth / 2,
+		 geometry().height() );
+  }
+  
+  if ( handleUnderMouse == Middle )
+  {
+    setGeometry( 0 - radius - frameWidth / 2,
+                 0 - radius - frameWidth / 2,
+		 desk->width() + 2 * radius + frameWidth,
+		 desk->height() + 2 * radius + frameWidth );
+  }
+}
