@@ -23,16 +23,19 @@
 #include <QDebug>
 #include <QRegion>
 #include <QCursor>
-#include <QX11Info>
+//#include <QX11Info>
 #include <QPainterPath>
 #include <QMouseEvent>
 #include <QApplication>
 #include <QDesktopWidget>
-#include <QMainWindow>
-
+//#include <QMainWindow>
 #include <QDialog>
 
-class regionselection : public QDialog
+#include "QvkSettings.h"
+
+
+//class regionselection : public QDialog
+class regionselection : public QWidget
 { 
 Q_OBJECT
 public:
@@ -56,7 +59,7 @@ public slots:
   int getWidth();
   int getXRecordArea();
   int getYRecordArea();
-  void saveSettings();
+  //void saveSettings();
 
 private slots:
   void moveTopLeft     ( QMouseEvent *event );
@@ -89,7 +92,7 @@ protected:
   void mouseMoveEvent( QMouseEvent *event );
   void mousePressEvent( QMouseEvent *event );
   void mouseReleaseEvent ( QMouseEvent * event );
-  
+  void mouseDoubleClickEvent( QMouseEvent *event);
   void paintEvent( QPaintEvent *event );
   QPainter * painter;
   
@@ -118,6 +121,8 @@ private:
   QRect printSizeRectForMask;
   QRect HandleMiddleForMask;
   
-  int Setting_Area_NoShowInTaskBar;
+  QvkSettings vkSettings;
+  
+  // int Setting_Area_NoShowInTaskBar;
 };
 #endif
