@@ -10,6 +10,8 @@
 #include <QFileDialog>
 #include <QLabel>
 
+#include "ui_QvkMailDialog.h"
+
 class QvkMail: public QObject
 { 
 Q_OBJECT
@@ -29,6 +31,7 @@ private slots:
   QString lastMovie();
   void selection();
   QStringList selectedMail();
+  void closeDialog();
 
 
 signals:
@@ -38,9 +41,13 @@ protected:
 
   
 private:
-  QDialog * dialog;
-  QRadioButton * mailRadioButton;
-  QRadioButton * mailSelectedRadioButton;
+  QDialog *newDialog;
+//  QDialog * dialog;
+//  QRadioButton * mailRadioButton;
+//  QRadioButton * mailSelectedRadioButton;
+  
+  Ui_MailDialog myUiMailDialog;
+
 };
 
 #endif
