@@ -52,11 +52,12 @@ void QvkSettings::readAll()
       VideoPlayer = settings.value( "Videoplayer" ).toString();
       Minimized = settings.value( "Minimized", 0 ).toUInt();
       Countdown = settings.value( "Countdown", 0 ).toUInt();
+      Recorder = settings.value( "Recorder", "ffmpeg" ).toString();
     settings.endGroup();
     
     settings.beginGroup( "Videooptions" );
       Frames = settings.value( "Frames", 25 ).toInt();
-      VideoCodec = settings.value( "Videocodec", "mpeg4" ).toString();
+      VideoCodec = settings.value( "Videocodec", "libx264" ).toString();
       AudioCodec = settings.value( "Audiocodec", "libmp3lame" ).toString();
       VideoContainer = settings.value( "Format", "mkv" ).toString();
       HideMouse = settings.value( "HideMouse").toUInt();
@@ -77,12 +78,19 @@ void QvkSettings::readAll()
     settings.endGroup();
 
     settings.beginGroup( "Webcam" );
-	webcamX = settings.value( "X", 0 ).toUInt();
-	webcamY = settings.value( "Y", 0 ).toUInt();
+        webcamOnOff = settings.value( "OnOff", 0 ).toUInt();
+	webcamX = settings.value( "X", 400 ).toUInt();
+	webcamY = settings.value( "Y", 400 ).toUInt();
 	webcamWidth = settings.value( "Width", 320 ).toUInt();
 	webcamHeight = settings.value( "Height", 240 ).toUInt();
 	webcamMirrored = settings.value( "Mirrored", false ).toBool();
-	webcamBorder = settings.value( "Border" ).toBool();
+	webcamBorder = settings.value( "Border", true ).toBool();
+	webcamOverFullScreen = settings.value( "OverFullScreen", false ).toBool();
+    settings.endGroup();
+    
+    settings.beginGroup( "Magnifier" );
+        magnifierOnOff = settings.value( "OnOff", 0 ).toUInt();
+	magnifierFormValue = settings.value( "FormValue", 2 ).toUInt();
     settings.endGroup();
 }
 
@@ -171,6 +179,12 @@ int QvkSettings::getHideMouse()
   return HideMouse; 
 }
 
+QString QvkSettings::getRecorder()
+{
+  return Recorder;  
+}
+
+
 
 // Gui
 int QvkSettings::getX()
@@ -216,6 +230,11 @@ int QvkSettings::getAreaHeight()
 }
 
 // Webcam
+int QvkSettings::getWebcamOnOff()
+{
+  return webcamOnOff; 
+}
+
 int QvkSettings::getWebcamX()
 {
   return webcamX;
@@ -245,3 +264,19 @@ bool QvkSettings::getWebcamBorder()
 {
   return webcamBorder;  
 }
+
+bool QvkSettings::getWebcamOverFullScreen()
+{
+  return webcamOverFullScreen;
+}
+
+// Magnifier
+int QvkSettings::getMagnifierOnOff()
+{
+  return magnifierOnOff;
+}
+
+int QvkSettings::getMagnifierFormValue()
+{
+  return magnifierFormValue; 
+}
\ No newline at end of file
