@@ -1,11 +1,8 @@
 #include "QvkWebcamController.h" 
-#include <QTimer>
-#include <QSettings>
 
 QvkWebcamController::QvkWebcamController( QCheckBox *myCheckBox, QComboBox *myComboBox, QCheckBox *myMirrorCheckBox, 
 					  QFrame *myRotateFrame ,QDial *myRotateDial, QRadioButton *myRadioButtonTopMiddle, QRadioButton *myRadioButtonRightMiddle, QRadioButton *myRadioButtonBottomMiddle, QRadioButton *myRadioButtonLeftMiddle )
 {
-  
   vkSettings.readAll();
   
   checkBox = myCheckBox;
@@ -59,9 +56,20 @@ QvkWebcamController::QvkWebcamController( QCheckBox *myCheckBox, QComboBox *myCo
   
   webcamWindow = new QvkWebcamWindow();
   connect( webcamWindow, SIGNAL( closeWebcamWindow() ), SLOT( webcamCloseEvent() ) );
-  webcamWindow->setGeometry( vkSettings.getWebcamX(), vkSettings.getWebcamY(), vkSettings.getWebcamWidth(), vkSettings.getWebcamHeight() );
+  connect( webcamWindow, SIGNAL( enterEventWebcamWindow() ), SLOT( enterEventWebcamWindow() ) );
+  connect( webcamWindow, SIGNAL( leaveEventWebcamWindow() ), SLOT( leaveEventWebcamWindow() ) );
+  connect( webcamWindow, SIGNAL( resizeEventWebcamWindow() ), SLOT( resizeEventWebcamWindow() ) );
   
   connect( myWebcamWatcher, SIGNAL( readWebcamNames( QStringList ) ), this, SLOT( readWebcams( QStringList ) ) );
+  
+  
+  mirrorWidget = new QvkWidgetcircle( webcamWindow );
+  mirrorWidget->resize( 30, 30);
+  mirrorWidget->setToolTip( "Gespiegelt" );
+  mirrorWidget->setColor( Qt::blue );
+  mirrorWidget->setVisible ( false );
+  connect( mirrorWidget, SIGNAL( clicked( bool ) ), SLOT( setMirrorOnOff( bool ) ) );
+  
 }
 
 
@@ -79,6 +87,7 @@ void QvkWebcamController::saveSettings()
     settings.setValue( "Width", webcamWindow->getValueWidth() );
     settings.setValue( "Height", webcamWindow->getValueHeight() );
     settings.setValue( "Border", webcamWindow->getValueBorder() );
+    settings.setValue( "OverFullScreen", webcamWindow->getOverFullScreen() );
   settings.endGroup();
 }
 
@@ -112,6 +121,9 @@ void QvkWebcamController::webcamCloseEvent()
 {
   checkBox->setCheckState( Qt::CheckState( Qt::Unchecked ) );
   comboBox->setEnabled( true );
+  mirrorCheckBox->setEnabled( false );
+  rotateFrame->setEnabled( false );
+  
   if ( captureThread->running )
     captureThread->stop();
   
@@ -132,16 +144,13 @@ void QvkWebcamController::setMirrorOnOff( bool value )
  */
 void QvkWebcamController::setWebcamOnOff( bool value )
 {
-  if ( value == false )
+  if ( value == false )    
   {
     captureThread->stop();
     webcamWindow->close();
-    comboBox->setEnabled( true );
-    mirrorCheckBox->setEnabled( false );
-    rotateFrame->setEnabled( false );
     return;
   }
- 
+
   QString index = comboBox->currentText().left( 2 ).right( 1 );
   QProcess Process;
   Process.start( "lsof /dev/video" + index );
@@ -166,11 +175,11 @@ void QvkWebcamController::setWebcamOnOff( bool value )
     (void) WebcamBusyDialog;
   
     qDebug() << "[vokoscreen] webcam device /dev/video" + index + " " + comboBox->currentText().remove( 0, 4 ) + " is busy by " + usedBy;
-    checkBox->setCheckState( Qt::CheckState( Qt::Unchecked ) );
+    checkBox->setChecked( Qt::Unchecked );
     return;
   }
   
-  if ( value == true )
+  if ( value == true )    
   {
     comboBox->setEnabled( false );
     mirrorCheckBox->setEnabled( true );
@@ -178,8 +187,6 @@ void QvkWebcamController::setWebcamOnOff( bool value )
     webcamWindow->show();
     webcamWindow->currentDevice = "/dev/video" + index;
     captureThread->start( "/dev/video" + index );
-    if ( not vkSettings.getWebcamBorder( ) ) 
-      webcamWindow->actionBorder->trigger();
   }
 }
 
@@ -270,3 +277,24 @@ void QvkWebcamController::webcamChangedEvent( QStringList deviceList )
     comboBox->setEnabled( true );
   }
 }
+
+void QvkWebcamController::enterEventWebcamWindow()
+{
+   //qDebug() << "In";
+   mirrorWidget->setVisible( true );
+}
+
+void QvkWebcamController::leaveEventWebcamWindow()
+{
+  //qDebug() << "Out";
+  mirrorWidget->setVisible( false );
+}
+
+void QvkWebcamController::resizeEventWebcamWindow()
+{
+  int count = 1;
+  int x = 0;  
+  int y = webcamWindow->height()/(count+1);
+  mirrorWidget->move( webcamWindow->width()-40, y * ++x );
+
+}
\ No newline at end of file
